@@ -54,15 +54,13 @@ def choose_function_or_lines(choice_file: Path, kwargs_dict: dict[str, object])
 
 
 def get_command_streamlit(choice_file: Path, environment: str, repo_root: Optional[Path]) -> str:
-    import socket
-    s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
-    try:
-        s.connect(("8.8.8.8", 1))
-        local_ip_v4 = s.getsockname()[0]
-    except Exception:
-        local_ip_v4 = socket.gethostbyname(socket.gethostname())
-    finally:
-        s.close()
+    # from machineconfig.scripts.python.helpers_utils.path import get_machine_specs
+    from machineconfig.scripts.python.nw.address import select_lan_ipv4
+    res = select_lan_ipv4(prefer_vpn=False)
+    if res is None:
+        raise RuntimeError("Could not determine local LAN IPv4 address for streamlit app.")
+    local_ip_v4 = res
+
     computer_name = platform.node()
     port = 8501
     toml_path: Optional[Path] = None
@@ -108,8 +106,11 @@ echo "http://{local_ip_v4}:{port}"
 qrterminal "http://{computer_name}:{port}"
 echo "http://{computer_name}:{port}"
 """
-    from machineconfig.utils.code import run_shell_script
-    run_shell_script(script)
+    # from machineconfig.utils.code import run_shell_script
+    # run_shell_script(script)
+    from machineconfig.utils.code import print_code
+    print_code(code=script, lexer="shell", desc="Streamlit QR Codes and URLs")
+
     message = f"🚀 Streamlit app is running @:\n1- http://{local_ip_v4}:{port}\n2- http://{computer_name}:{port}\n3- http://localhost:{port}"
     from rich.panel import Panel
     from rich import print as rprint
