@@ -1,4 +1,19 @@
-"""Devops Devapps Install"""
+"""Devops Devapps Install
+
+
+sudo apt update && sudo apt install -y \
+  git gcc g++ clang \
+  yasm nasm pkg-config \
+  meson ninja-build \
+  autoconf automake libtool \
+  libx11-dev libxext-dev libxrandr-dev libxrender-dev libxss-dev \
+  libvdpau-dev libgl1-mesa-dev libegl1-mesa-dev libxv-dev \
+  libasound2-dev libpulse-dev \
+  libfribidi-dev libfreetype-dev libfontconfig1-dev libharfbuzz-dev \
+  libjpeg-dev libssl-dev zlib1g-dev python3-pip
+
+
+"""
 
 import typer
 from typing import Annotated, Optional
@@ -151,6 +166,11 @@ def install_clis(clis_names: list[str]):
             from machineconfig.utils.installer_utils.install_from_url import install_from_github_url
             install_from_github_url(github_url=a_cli_name)
             continue
+        elif a_cli_name.startswith("https://") or a_cli_name.startswith("http://"):
+            print(f"⏳ Installing from binary URL: {a_cli_name} ...")
+            from machineconfig.utils.installer_utils.install_from_url import install_from_binary_url
+            install_from_binary_url(a_cli_name)
+            continue
         selected_installer = None
         for installer in all_installers:
             app_name = installer["appName"]
